==> crux-dev-5.0.0.jar: org/cruxframework/crux/gwt/rebind/FocusWidgetFactory.java <==
/*
 * Copyright 2011 cruxframework.org.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package org.cruxframework.crux.gwt.rebind;

import org.cruxframework.crux.core.rebind.screen.widget.WidgetCreator;
import org.cruxframework.crux.core.rebind.screen.widget.WidgetCreatorContext;
import org.cruxframework.crux.core.rebind.screen.widget.creator.FocusableFactory;
import org.cruxframework.crux.core.rebind.screen.widget.creator.HasAllFocusHandlersFactory;
import org.cruxframework.crux.core.rebind.screen.widget.creator.HasAllKeyHandlersFactory;
import org.cruxframework.crux.core.rebind.screen.widget.creator.HasAllMouseHandlersFactory;
import org.cruxframework.crux.core.rebind.screen.widget.creator.HasAllTouchHandlersFactory;
import org.cruxframework.crux.core.rebind.screen.widget.creator.event.ClickEvtBind;
import org.cruxframework.crux.core.rebind.screen.widget.creator.event.DoubleClickEvtBind;
import org.cruxframework.crux.core.rebind.screen.widget.declarative.TagAttribute;
import org.cruxframework.crux.core.rebind.screen.widget.declarative.TagAttributes;
import org.cruxframework.crux.core.rebind.screen.widget.declarative.TagEvent;
import org.cruxframework.crux.core.rebind.screen.widget.declarative.TagEvents;

/**
 * This is the base factory class for widgets that can receive focus.
 *
 * @author Thiago Bustamante
 *
 */
@TagAttributes({
	@TagAttribute(value="enabled", type=Boolean.class)
})
@TagEvents({
	@TagEvent(ClickEvtBind.class),
	@TagEvent(DoubleClickEvtBind.class)
})
public abstract class FocusWidgetFactory <C extends WidgetCreatorContext> extends WidgetCreator<C> 
			implements FocusableFactory<C>, HasAllMouseHandlersFactory<C>, HasAllKeyHandlersFactory<C>, 
			HasAllFocusHandlersFactory<C>, HasAllTouchHandlersFactory<C>
{
}

==> crux-dev-5.3.2.jar: org/cruxframework/crux/gwt/rebind/FocusWidgetFactory.java <==
/*
 * Copyright 2011 cruxframework.org.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package org.cruxframework.crux.gwt.rebind;

import org.cruxframework.crux.core.rebind.screen.widget.WidgetCreator;
import org.cruxframework.crux.core.rebind.screen.widget.WidgetCreatorContext;
import org.cruxframework.crux.core.rebind.screen.widget.creator.FocusableFactory;
import org.cruxframework.crux.core.rebind.screen.widget.creator.HasAllFocusHandlersFactory;
import org.cruxframework.crux.core.rebind.screen.widget.creator.HasAllKeyHandlersFactory;
import org.cruxframework.crux.core.rebind.screen.widget.creator.HasAllMouseHandlersFactory;
import org.cruxframework.crux.core.rebind.screen.widget.creator.HasAllTouchHandlersFactory;
import org.cruxframework.crux.core.rebind.screen.widget.creator.HasEnabledFactory;
import org.cruxframework.crux.core.rebind.screen.widget.creator.event.ClickEvtBind;
import org.cruxframework.crux.core.rebind.screen.widget.creator.event.DoubleClickEvtBind;
import org.cruxframework.crux.core.rebind.screen.widget.declarative.TagAttribute;
import org.cruxframework.crux.core.rebind.screen.widget.declarative.TagAttributes;
import org.cruxframework.crux.core.rebind.screen.widget.declarative.TagEvent;
import org.cruxframework.crux.core.rebind.screen.widget.declarative.TagEvents;

/**
 * This is the base factory class for widgets that can receive focus.
 *
 * @author Thiago Bustamante
 *
 */
@TagAttributes({
	@TagAttribute(value="enabled", type=Boolean.class)
})
@TagEvents({
	@TagEvent(ClickEvtBind.class),
	@TagEvent(DoubleClickEvtBind.class)
})
public abstract class FocusWidgetFactory <C extends WidgetCreatorContext> extends WidgetCreator<C> 
			implements FocusableFactory<C>, HasAllMouseHandlersFactory<C>, HasAllKeyHandlersFactory<C>, 
			HasAllFocusHandlersFactory<C>, HasAllTouchHandlersFactory<C>, HasEnabledFactory<C>
{
}
